# alien-minimalistic

The alien-minimalistic is a modern responsive Jekyll theme designed to be used right off the box with very minimal set up time. Since the theme's design aims to highlight the writer's background, apart from providing a clean templated blogging system, it is very helpful to students and professionals to showcase their careers in a coherent manner.

![](https://github.com/mrcivvy/alien-minimalistic/blob/master/_screenshots/home-page.png)

## Installation

### Approach I: Ruby gem

1. Set up a jekyll site quickly using the default Minima theme, run the following command:

```shell
jekyll new <myblog>
```

2. Add this line to your Jekyll site's `Gemfile`:

```ruby
gem "alien-minimalistic"
```

3. Add this line to your Jekyll site's `_config.yml`:

```yaml
theme: alien-minimalistic
```

4. Execute the command:

```shell
$ bundle install
```

Or install it yourself:

```shell
$ gem install alien-minimalistic
```

5. Create the following files at the root of your site:

```shell
about.md
articles.md
contact.md
404.md
```

6. Add front matter to these files to specify the layout and title. Note that the layout names and the permalink location names are the same as the files names that you created in the previous step.

For example, in the about.md file the front matter would be:

```shell
---
layout: about
title: About - Sitename
---
```

7. Add the following front matter to your 404.md file to keep up the theme's stylesheeting for it.

```html
---
layout: 404
title: Page not found - Alienspline
permalink: /404.html
---
```

8. Make the permalinks pretty by setting the following in your `_config.yml`

```shell
permalink: pretty
```

9. Follow the notes mentioned in the `Usage` section to update the theme with your site's data

### Approach II: Github repository

1. Clone the Jekyll theme from the repository using the command, `git clone https://github.com/mrcivvy/alien-minimalistic.git`
2. Update the theme with your data (See the `Usage` section)
3. Remember to pull updates from this Github repository when new releases are rolled out

## Usage

The theme has been designed to require very minimal changes if you plan to use it right off the box. All you need to do is just define the following `content editable variables` in the `_config.yml` file of your site,

#### Content Editable Variables

```yaml
title (The title of your site)
first-name (Your first name)
middle-name (Your middle name)
last-name (Your last name)
email (Your email address - requires a registered formspree.io email address for the contact form to work.)
resume-link (Link to your resume)
disqus (URL of your disqus's embed.js script to enable comments for your site's articles)
tagline (The tagline that is displayed in the home page)
description (The description of your site underneath the tag line)
contact-page-message (A message for your users in the contact page)
favicon (The path to the site's favicon)
profile-picture (The path to your profile picture which will be displayed in the 'About' section)
home-background (The path to the background image in the home page)
primary-color (The hexcode of the primary color of the site)
secondary-color (The hexcode of the secondary-color of the site)
github_page (The link to your Github account)
twitter_page (The link to your Twitter account)
linkedin_page (The link to your Linkedin account)
```

You'll need a [disqus](https://disqus.com/) account for the comments section and a [formspree.io](https://formspree.io/) account for the contact page form. Disqus provides a javascript file to embed in your site so that it can track the comments made by the users of your site. Setting the URL to the javascript file, to the `disqus` variable in the `_config.yml` file should enable Disqus on your site. To set up formspree for your site, you'll need to just set the `email` variable in the `_config.yml` file.

However, if you need some customisation, the theme's `_layouts`, `_includes`, `_sass` and `_assets` folders can be overridden by following the standard procedure described on Jekyll's site [here](https://jekyllrb.com/docs/themes/).

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/mrcivvy/alien-minimalistic. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](http://contributor-covenant.org) code of conduct.

## Development

To set up your environment to develop this theme, run `bundle install`.

To test your theme, run `bundle exec jekyll serve` and open your browser at `http://localhost:4000`. This starts a Jekyll server using your theme and the contents. As you make modifications to your theme and to your content, your site will regenerate and you should see the changes in the browser after a refresh.

When your theme is released, only the files in `_layouts`, `_includes`, `_sass` and `assets` tracked with Git will be bundled. To add a custom directory to your theme-gem, please edit the regexp in alien-minimalistic.gemspec accordingly.

## License

The theme is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).
